@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include "gst-cutter-console-output.h"
@@ -29,11 +29,6 @@
 #include <cutter/cut-verbose-level.h>
 #include <cutter/cut-enum-types.h>
 
-static const GstElementDetails cutter_console_output_details =
-    GST_ELEMENT_DETAILS("Cutter console output",
-                        "Cutter console output",
-                        "Cutter console output",
-                        "g新部 Hiroyuki Ikezoe  <poincare@ikezoe.net>");
 static GstStaticPadTemplate cutter_console_output_sink_template_factory =
     GST_STATIC_PAD_TEMPLATE("sink",
                             GST_PAD_SINK,
@@ -51,7 +46,8 @@ struct _GstCutterConsoleOutputPrivate
     gchar *verbose_level_string;
 };
 
-GST_BOILERPLATE(GstCutterConsoleOutput, gst_cutter_console_output, GstBaseSink, GST_TYPE_BASE_SINK);
+#define gst_cutter_console_output_parent_class parent_class
+G_DEFINE_TYPE(GstCutterConsoleOutput, gst_cutter_console_output, GST_TYPE_BASE_SINK);
 
 enum
 {
@@ -75,23 +71,13 @@ static gboolean      stop            (GstBaseSink *base_sink);
 static GstFlowReturn render          (GstBaseSink *base_sink,
                                       GstBuffer   *buffer);
 
-static void
-gst_cutter_console_output_base_init (gpointer klass)
-{
-    GstElementClass *element_class = GST_ELEMENT_CLASS(klass);
-
-    gst_element_class_add_pad_template(element_class,
-        gst_static_pad_template_get(&cutter_console_output_sink_template_factory));
-
-    gst_element_class_set_details(element_class, &cutter_console_output_details);
-}
-
 static void
 gst_cutter_console_output_class_init (GstCutterConsoleOutputClass * klass)
 {
     GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
     GstBaseSinkClass *base_sink_class = GST_BASE_SINK_CLASS(klass);
     GParamSpec *spec;
+    GstElementClass *element_class = GST_ELEMENT_CLASS(klass);
 
     parent_class = g_type_class_peek_parent(klass);
 
@@ -118,11 +104,19 @@ gst_cutter_console_output_class_init (GstCutterConsoleOutputClass * klass)
     g_object_class_install_property(gobject_class, ARG_VERBOSE_LEVEL, spec);
 
     g_type_class_add_private(gobject_class, sizeof(GstCutterConsoleOutputPrivate));
+
+    gst_element_class_add_pad_template(element_class,
+        gst_static_pad_template_get(&cutter_console_output_sink_template_factory));
+
+    gst_element_class_set_metadata(element_class,
+                                   "Cutter console output",
+                                   "Cutter console output",
+                                   "Cutter console output",
+                                   "g新部 Hiroyuki Ikezoe  <poincare@ikezoe.net>");
 }
 
 static void
-gst_cutter_console_output_init (GstCutterConsoleOutput *cutter_console_output,
-                                GstCutterConsoleOutputClass * klass)
+gst_cutter_console_output_init (GstCutterConsoleOutput *cutter_console_output)
 {
     GstCutterConsoleOutputPrivate *priv = GST_CUTTER_CONSOLE_OUTPUT_GET_PRIVATE(cutter_console_output);
 
@@ -235,17 +229,16 @@ stop (GstBaseSink *base_sink)
 static GstFlowReturn
 render (GstBaseSink *base_sink, GstBuffer *buffer)
 {
-    guint size;
-    guint8 *data;
     GstCutterConsoleOutputPrivate *priv;
+    GstMapInfo info;
 
     priv = GST_CUTTER_CONSOLE_OUTPUT_GET_PRIVATE(base_sink);
-    size = GST_BUFFER_SIZE(buffer);
-    data = GST_BUFFER_DATA(buffer);
+    gst_buffer_map(buffer, &info, GST_MAP_READ);
 
-    if (size > 0)
+    if (info.size > 0)
         cut_stream_reader_read(CUT_STREAM_READER(priv->reader),
-                               (gchar *)data, size);
+                               (gchar *)info.data, info.size);
+    gst_buffer_unmap(buffer, &info);
 
     return GST_FLOW_OK;
 }
