@@ -17,10 +17,6 @@ require 'rd-visitor-util'
 require "rubygems"
 require "fast_gettext/po_file"
 
-if Object.const_defined?(:Encoding)
-  Encoding.default_external = Encoding::UTF_8
-end
-
 module RD
   class RD2RefEntryVisitor < RDVisitor
     include ERB::Util
@@ -114,7 +110,12 @@ module RD
       when "# RT"
         apply_to_RT(lines.join)
       when "# note"
-        contents = lines[1..-1].collect {|line| apply_to_String(line)}
+        contents = []
+        sub_content = lines[1..-1].join("")
+        sub_tree = RD::RDTree.new("=begin\n#{sub_content}\n=end\n")
+        sub_tree.root.children.each do |child|
+          contents << child.accept(self)
+        end
         tag("note", {}, contents.join("").chomp)
       else
         contents = lines.collect {|line| apply_to_String(line)}
